public inbox for kvm@vger.kernel.org
 help / color / mirror / Atom feed
From: Yosry Ahmed <yosry.ahmed@linux.dev>
To: Sean Christopherson <seanjc@google.com>
Cc: Paolo Bonzini <pbonzini@redhat.com>,
	kvm@vger.kernel.org, linux-kernel@vger.kernel.org,
	Yosry Ahmed <yosryahmed@google.com>,
	Yosry Ahmed <yosry.ahmed@linux.dev>
Subject: [PATCH 08/12] KVM: selftests: Use 'leaf' instead of hugepage to describe EPT entries
Date: Wed,  1 Oct 2025 14:58:12 +0000	[thread overview]
Message-ID: <20251001145816.1414855-9-yosry.ahmed@linux.dev> (raw)
In-Reply-To: <20251001145816.1414855-1-yosry.ahmed@linux.dev>

From: Yosry Ahmed <yosryahmed@google.com>

The assertions use 'hugepage' to describe a terminal EPT entry, but
'leaf' is more accruate as a PG_LEVEL_4K EPT entry is a leaf but not a
hugepage. The distincion will be useful in coming changes that will pass
the value around and 'leaf' is clearer than hugepage or page_size.

Leave the EPT bit named page_size to keep it conforming to the manual.

Signed-off-by: Yosry Ahmed <yosry.ahmed@linux.dev>
---
 tools/testing/selftests/kvm/lib/x86/vmx.c | 10 +++++-----
 1 file changed, 5 insertions(+), 5 deletions(-)

diff --git a/tools/testing/selftests/kvm/lib/x86/vmx.c b/tools/testing/selftests/kvm/lib/x86/vmx.c
index 04c4b97bcd1e7..673756b27e903 100644
--- a/tools/testing/selftests/kvm/lib/x86/vmx.c
+++ b/tools/testing/selftests/kvm/lib/x86/vmx.c
@@ -380,15 +380,15 @@ static void nested_create_pte(struct kvm_vm *vm,
 			pte->address = vm_alloc_page_table(vm) >> vm->page_shift;
 	} else {
 		/*
 		 * Entry already present.  Assert that the caller doesn't want
 		 * a hugepage at this level, and that there isn't a hugepage at
 		 * this level.
 		 */
 		TEST_ASSERT(current_level != target_level,
-			    "Cannot create hugepage at level: %u, nested_paddr: 0x%lx",
+			    "Cannot create leaf entry at level: %u, nested_paddr: 0x%lx",
 			    current_level, nested_paddr);
 		TEST_ASSERT(!pte->page_size,
-			    "Cannot create page table at level: %u, nested_paddr: 0x%lx",
+			    "Leaf entry already exists at level: %u, nested_paddr: 0x%lx",
 			    current_level, nested_paddr);
 	}
 }
@@ -380,15 +380,15 @@ static void nested_create_pte(struct kvm_vm *vm,
 	} else {
 		/*
-		 * Entry already present.  Assert that the caller doesn't want
-		 * a hugepage at this level, and that there isn't a hugepage at
-		 * this level.
+		 * Entry already present.  Assert that the caller doesn't want a
+		 * leaf entry at this level, and that there isn't a leaf entry
+		 * at this level.
 		 */
 		TEST_ASSERT(current_level != target_level,
-- 
2.51.0.618.g983fd99d29-goog


  parent reply	other threads:[~2025-10-01 14:58 UTC|newest]

Thread overview: 33+ messages / expand[flat|nested]  mbox.gz  Atom feed  top
2025-10-01 14:58 [PATCH 00/12] Extend test coverage for nested SVM Yosry Ahmed
2025-10-01 14:58 ` [PATCH 01/12] KVM: selftests: Minor improvements to asserts in test_vmx_nested_state() Yosry Ahmed
2025-10-09 21:44   ` Jim Mattson
2025-10-01 14:58 ` [PATCH 02/12] KVM: selftests: Extend vmx_set_nested_state_test to cover SVM Yosry Ahmed
2025-10-09 22:40   ` Jim Mattson
2025-10-09 23:13     ` Yosry Ahmed
2025-10-01 14:58 ` [PATCH 03/12] KVM: selftests: Extend vmx_close_while_nested_test " Yosry Ahmed
2025-10-09 22:44   ` Jim Mattson
2025-10-01 14:58 ` [PATCH 04/12] KVM: selftests: Extend vmx_nested_tsc_scaling_test " Yosry Ahmed
2025-10-09 22:51   ` Jim Mattson
2025-10-09 23:19     ` Yosry Ahmed
2025-10-01 14:58 ` [PATCH 05/12] KVM: selftests: Remove invalid CR3 test from vmx_tsc_adjust_test Yosry Ahmed
2025-10-09 22:55   ` Jim Mattson
2025-10-09 23:24     ` Yosry Ahmed
2025-10-01 14:58 ` [PATCH 06/12] KVM: selftests: Extend vmx_tsc_adjust_test to cover SVM Yosry Ahmed
2025-10-09 23:27   ` Jim Mattson
2025-10-01 14:58 ` [PATCH 07/12] KVM: selftests: Pass the root HVA directly to nested mapping functions Yosry Ahmed
2025-10-09 23:30   ` Jim Mattson
2025-10-01 14:58 ` Yosry Ahmed [this message]
2025-10-13 18:34   ` [PATCH 08/12] KVM: selftests: Use 'leaf' instead of hugepage to describe EPT entries Jim Mattson
2025-10-13 21:41   ` Sean Christopherson
2025-10-13 22:25     ` Yosry Ahmed
2025-10-13 22:58       ` Sean Christopherson
2025-10-13 23:13         ` Yosry Ahmed
2025-10-15 18:20           ` Sean Christopherson
2025-10-01 14:58 ` [PATCH 09/12] KVM: selftests: Move all PTE accesses into nested_create_pte() Yosry Ahmed
2025-10-13 18:41   ` Jim Mattson
2025-10-01 14:58 ` [PATCH 10/12] KVM: selftests: Move EPT-specific init outside nested_create_pte() Yosry Ahmed
2025-10-13 18:52   ` Jim Mattson
2025-10-01 14:58 ` [PATCH 11/12] KVM: selftests: Refactor generic nested mapping outside VMX code Yosry Ahmed
2025-10-13 19:04   ` Jim Mattson
2025-10-01 14:58 ` [PATCH 12/12] KVM: selftests: Extend vmx_dirty_log_test to cover SVM Yosry Ahmed
2025-10-01 17:37 ` [PATCH 00/12] Extend test coverage for nested SVM Yosry Ahmed

Reply instructions:

You may reply publicly to this message via plain-text email
using any one of the following methods:

* Save the following mbox file, import it into your mail client,
  and reply-to-all from there: mbox

  Avoid top-posting and favor interleaved quoting:
  https://en.wikipedia.org/wiki/Posting_style#Interleaved_style

* Reply using the --to, --cc, and --in-reply-to
  switches of git-send-email(1):

  git send-email \
    --in-reply-to=20251001145816.1414855-9-yosry.ahmed@linux.dev \
    --to=yosry.ahmed@linux.dev \
    --cc=kvm@vger.kernel.org \
    --cc=linux-kernel@vger.kernel.org \
    --cc=pbonzini@redhat.com \
    --cc=seanjc@google.com \
    --cc=yosryahmed@google.com \
    /path/to/YOUR_REPLY

  https://kernel.org/pub/software/scm/git/docs/git-send-email.html

* If your mail client supports setting the In-Reply-To header
  via mailto: links, try the mailto: link
Be sure your reply has a Subject: header at the top and a blank line before the message body.
This is a public inbox, see mirroring instructions
for how to clone and mirror all data and code used for this inbox